# Copyright 2012, 2013 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from pyramid.httpexceptions import HTTPMovedPermanently

from charmworld.testing import (
    ViewTestBase,
    WebTestBase,
)
from charmworld.views import search


RETURN_VAL = {
    'results': [],
    'search_time': 0.0,
    'result_total': 0,
    'matches': 0,
}


class SearchTests(ViewTestBase):

    def test_search(self):
        terms = {"search_text": 'foo'}
        request = self.getRequest(params=terms)
        with self.assertRaises(HTTPMovedPermanently) as e:
            search.search(request)
        self.assertIn('/q/foo', e.exception.location)

    def test_search_multiple(self):
        terms = {"search_text": 'foo bar'}
        request = self.getRequest(params=terms)
        with self.assertRaises(HTTPMovedPermanently) as e:
            search.search(request)
        self.assertIn('/q/foo/bar', e.exception.location)

    def test_search_with_space(self):
        terms = {"search_text": ' foo   bar '}
        request = self.getRequest(params=terms)
        with self.assertRaises(HTTPMovedPermanently) as e:
            search.search(request)
        self.assertIn('/q/foo/bar', e.exception.location)


class SearchJSONTests(WebTestBase):

    def test_search_json_obsolete(self):
        obsolete_message = 'no longer supported'
        resp = self.app.get('/search/json', status=410)
        self.assertIn(obsolete_message, resp.body)
